NAME
PDL::GSL::INTERP - PDL interface to Interpolation routines in GSL
DESCRIPTION
This is an interface to the interpolation package present in the GNU Scientific Library.
SYNOPSIS
use PDL;
use PDL::GSL::INTERP;
my $x = sequence(10);
my $y = exp($x);
my $spl = PDL::GSL::INTERP->init('cspline',$x,$y);
my $res = $spl->eval(4.35);
$res = $spl->deriv(4.35);
$res = $spl->deriv2(4.35);
$res = $spl->integ(2.1,7.4);
NOMENCLATURE
Throughout this documentation we strive to use the same variables that are present in the original GSL documentation (see See Also). Oftentimes those variables are called a and b. Since good Perl coding practices discourage the use of Perl variables $a and $b, here we refer to Parameters a and b as $pa and $pb, respectively, and Limits (of domain or integration) as $la and $lb. #line 65 "lib/PDL/GSL/INTERP.pm"
FUNCTIONS
init
Signature: (double x(n); double y(n); gsl_spline *spl)
Types: (sbyte byte short ushort long ulong indx ulonglong longlong
float double ldouble)
The init method initializes a new instance of INTERP. It needs as input an interpolation type and two ndarrays holding the x and y values to be interpolated. The GSL routines require that x be monotonically increasing and a quicksort is performed by default to ensure that. You can skip the quicksort by passing the option {Sort => 0}.
The available interpolation types are :
- linear
- polynomial
- cspline (natural cubic spline)
- cspline_periodic (periodic cubic spline)
- akima (natural akima spline)
- akima_periodic (periodic akima spline)
Please check the GSL documentation for more information.
Usage:
$blessed_ref = PDL::GSL::INTERP->init($interp_method,$x,$y,$opt);
Example:
$x = sequence(10);
$y = exp($x);
$spl = PDL::GSL::INTERP->init('cspline',$x,$y)
$spl = PDL::GSL::INTERP->init('cspline',$x,$y,{Sort => 1}) #same as above
# no sorting done on x, user is certain that x is monotonically increasing
$spl = PDL::GSL::INTERP->init('cspline',$x,$y,{Sort => 0});
Broadcasts over its inputs.
init does not process bad values. It will set the bad-value flag of all output ndarrays if the flag is set for any of the input ndarrays.
eval
Signature: (double x(); double [o] out(); gsl_spline *spl;gsl_interp_accel *acc)
Types: (sbyte byte short ushort long ulong indx ulonglong longlong
float double ldouble)
The function eval returns the interpolating function at a given point. It will barf with an "input domain error" if you try to extrapolate.
Usage:
$result = $spl->eval($points);
Example:
my $res = $spl->eval($x)
Broadcasts over its inputs.
eval processes bad values. It will set the bad-value flag of all output ndarrays if the flag is set for any of the input ndarrays.
deriv
Signature: (double x(); double [o] out(); gsl_spline *spl;gsl_interp_accel *acc)
Types: (sbyte byte short ushort long ulong indx ulonglong longlong
float double ldouble)
The deriv function returns the derivative of the interpolating function at a given point. It will barf with an "input domain error" if you try to extrapolate.
Usage:
$result = $spl->deriv($points);
Example:
my $res = $spl->deriv($x)
Broadcasts over its inputs.
deriv does not process bad values. It will set the bad-value flag of all output ndarrays if the flag is set for any of the input ndarrays.
deriv2
Signature: (double x(); double [o] out(); gsl_spline *spl;gsl_interp_accel *acc)
Types: (sbyte byte short ushort long ulong indx ulonglong longlong
float double ldouble)
The deriv2 function returns the second derivative of the interpolating function at a given point. It will barf with an "input domain error" if you try to extrapolate.
Usage:
$result = $spl->deriv2($points);
Example:
my $res = $spl->deriv2($x)
Broadcasts over its inputs.
deriv2 does not process bad values. It will set the bad-value flag of all output ndarrays if the flag is set for any of the input ndarrays.
integ
Signature: (double a(); double b(); double [o] out(); gsl_spline *spl;gsl_interp_accel *acc)
Types: (sbyte byte short ushort long ulong indx ulonglong longlong
float double ldouble)
The integ function returns the integral of the interpolating function between two points. It will barf with an "input domain error" if you try to extrapolate.
Usage:
$result = $spl->integ($la,$lb);
Example:
my $res = $spl->integ($la,$lb)
Broadcasts over its inputs.
integ does not process bad values. It will set the bad-value flag of all output ndarrays if the flag is set for any of the input ndarrays.
BUGS
Feedback is welcome.
SEE ALSO
The GSL documentation for interpolation is online at https://www.gnu.org/software/gsl/doc/html/interp.html
AUTHOR
This file copyright (C) 2003 Andres Jordan <andresj@physics.rutgers.edu> All rights reserved. There is no warranty. You are allowed to redistribute this software/documentation under certain conditions. For details, see the file COPYING in the PDL distribution. If this file is separated from the PDL distribution, the copyright notice should be included in the file.
The GSL interpolation module was written by Gerard Jungman.